==> hibernate-core-6.0.0.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmNativeQueryCollectionLoadReturnType.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.hibernate.LockMode;


/**
 * <p>Java class for NativeQueryCollectionLoadReturnType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NativeQueryCollectionLoadReturnType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0"&gt;
 *         &lt;element name="return-property" type="{http://www.hibernate.org/xsd/orm/hbm}NativeQueryPropertyReturnType"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="alias" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="lock-mode" type="{http://www.hibernate.org/xsd/orm/hbm}LockModeEnum" default="read" /&gt;
 *       &lt;attribute name="role" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NativeQueryCollectionLoadReturnType", namespace = "http://www.hibernate.org/xsd/orm/hbm", propOrder = {
    "returnProperty"
})
public class JaxbHbmNativeQueryCollectionLoadReturnType implements Serializable, NativeQueryNonScalarRootReturn
{

    @XmlElement(name = "return-property", namespace = "http://www.hibernate.org/xsd/orm/hbm")
    protected List<JaxbHbmNativeQueryPropertyReturnType> returnProperty;
    @XmlAttribute(name = "alias", required = true)
    protected String alias;
    @XmlAttribute(name = "lock-mode")
    @XmlJavaTypeAdapter(Adapter8 .class)
    protected LockMode lockMode;
    @XmlAttribute(name = "role", required = true)
    protected String role;

    /**
     * Gets the value of the returnProperty property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a <CODE>set</CODE> method for the returnProperty property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getReturnProperty().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JaxbHbmNativeQueryPropertyReturnType }
     * 
     * 
     */
    public List<JaxbHbmNativeQueryPropertyReturnType> getReturnProperty() {
        if (returnProperty == null) {
            returnProperty = new ArrayList<JaxbHbmNativeQueryPropertyReturnType>();
        }
        return this.returnProperty;
    }

    /**
     * Gets the value of the alias property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAlias() {
        return alias;
    }

    /**
     * Sets the value of the alias property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAlias(String value) {
        this.alias = value;
    }

    /**
     * Gets the value of the lockMode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public LockMode getLockMode() {
        if (lockMode == null) {
            return new Adapter8().unmarshal("read");
        } else {
            return lockMode;
        }
    }

    /**
     * Sets the value of the lockMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLockMode(LockMode value) {
        this.lockMode = value;
    }

    /**
     * Gets the value of the role property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRole() {
        return role;
    }

    /**
     * Sets the value of the role property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRole(String value) {
        this.role = value;
    }

}

==> hibernate-core-6.2.2.Final-sources.jar: hbm/org/hibernate/boot/jaxb/hbm/spi/JaxbHbmNativeQueryCollectionLoadReturnType.java <==

package org.hibernate.boot.jaxb.hbm.spi;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.hibernate.LockMode;


/**
 * <p>Java class for NativeQueryCollectionLoadReturnType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="NativeQueryCollectionLoadReturnType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence maxOccurs="unbounded" minOccurs="0">
 *         <element name="return-property" type="{http://www.hibernate.org/xsd/orm/hbm}NativeQueryPropertyReturnType"/>
 *       </sequence>
 *       <attribute name="alias" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="lock-mode" type="{http://www.hibernate.org/xsd/orm/hbm}LockModeEnum" default="read" />
 *       <attribute name="role" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NativeQueryCollectionLoadReturnType", namespace = "http://www.hibernate.org/xsd/orm/hbm", propOrder = {
    "returnProperty"
})
public class JaxbHbmNativeQueryCollectionLoadReturnType implements Serializable, NativeQueryNonScalarRootReturn
{

    @XmlElement(name = "return-property", namespace = "http://www.hibernate.org/xsd/orm/hbm")
    protected List<JaxbHbmNativeQueryPropertyReturnType> returnProperty;
    @XmlAttribute(name = "alias", required = true)
    protected String alias;
    @XmlAttribute(name = "lock-mode")
    @XmlJavaTypeAdapter(Adapter8 .class)
    protected LockMode lockMode;
    @XmlAttribute(name = "role", required = true)
    protected String role;

    /**
     * Gets the value of the returnProperty property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the returnProperty property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getReturnProperty().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JaxbHbmNativeQueryPropertyReturnType }
     * 
     * 
     * @return
     *     The value of the returnProperty property.
     */
    public List<JaxbHbmNativeQueryPropertyReturnType> getReturnProperty() {
        if (returnProperty == null) {
            returnProperty = new ArrayList<>();
        }
        return this.returnProperty;
    }

    /**
     * Gets the value of the alias property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAlias() {
        return alias;
    }

    /**
     * Sets the value of the alias property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAlias(String value) {
        this.alias = value;
    }

    /**
     * Gets the value of the lockMode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public LockMode getLockMode() {
        if (lockMode == null) {
            return new Adapter8().unmarshal("read");
        } else {
            return lockMode;
        }
    }

    /**
     * Sets the value of the lockMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLockMode(LockMode value) {
        this.lockMode = value;
    }

    /**
     * Gets the value of the role property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRole() {
        return role;
    }

    /**
     * Sets the value of the role property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRole(String value) {
        this.role = value;
    }

}
